function [DIM,FOV,VOL,TYPE,longEpoch,numEpoch] = sdt_header(P)
% reads a header
% FORMAT [DIM FOV VOL TYPE longEpoch numEpoch] = sdt_header(P);
%
% P         - filename
% DIM       - image size       [i j k [l]] (voxels)
% FOV       - field of view (x_size, y_size, z_size cm and t_size images)
% VOL       - voxel size       [x y z [t]] (cm [images])
% TYPE      - datatype (integer - see spm_type)
% longEpoch - length of each epoch
% numEpoch  - number of epochs
%___________________________________________________________________________
%
% sdt_header reads variables into working memory from a sdt
% compatible header file.  If the header does not exist global defaults
% are used.  
%
% see also load_fMRI.h 
%
%__________________________________________________________________________
% sdt_header.m	 2000/5/2

% ensure correct suffix {.spr}
%---------------------------------------------------------------------------
P     = deblank(P);
q     = length(P);
if q>=4 & P(q - 3) == '.'; P = P(1:(q - 4)); end
P     = [P '.spr'];

P
% open header file
%---------------------------------------------------------------------------
fp   = fopen(P,'rt');

% read (struct) header_key
%---------------------------------------------------------------------------
fseek(fp,0,'bof');

DIM = fscanf(fp, 'dim: %d %d %d %d\n',4);
longEpoch = fscanf(fp, 'longEpoch: %d\n',1);
numEpoch = fscanf(fp, 'numEpoch: %d\n',1);
FOV = fscanf(fp, 'fov: %f %f %f %f\n',4);
VOL = fscanf(fp, 'interval: %f %f %f %f\n',4);
TYPE = fscanf(fp, 'dataType: %s',1);



if TYPE=='REAL' 
   TYPE='real*4'; 
else if TYPE=='WORD' 
      TYPE='int16'; 
   end
end


fclose(fp);

%_______________________________________________________________________

